.. include:: ../common.rst



|Time90|

Traversing 2D Arrays (nested loops)
======================================

Nested loops can be used to traverse 2D arrays row by row and column by column.

.. toctree::
   :maxdepth: 3

   topic-8-2-2D-array-loops-Day1.rst
   topic-8-2-2D-array-loops-Day2.rst
